@@ -8,15 +8,16 @@ Structures powering pywebcopy.
 
 """
 
-
-__all__ = ['CaseInsensitiveDict', 'RobotsTxt']
-
-
 from collections import MutableMapping
 
+import requests
+from requests.structures import OrderedDict
 from six.moves.urllib.robotparser import RobotFileParser
 
 
+__all__ = ['CaseInsensitiveDict', 'RobotsTxtParser']
+
+
 class CaseInsensitiveDict(MutableMapping):
     """ Flexible dictionary which creates less errors
     during lookups.
@@ -31,7 +32,7 @@ class CaseInsensitiveDict(MutableMapping):
     """
 
     def __init__(self, data=None, **kwargs):
-        self._store = dict()
+        self._store = OrderedDict()
         if data is None:
             data = {}
         self.update(data, **kwargs)
@@ -48,10 +49,10 @@ class CaseInsensitiveDict(MutableMapping):
     def __iter__(self):
         return (key for key, value in self._store.items())
 
-    def __len__(self):
+    def __len__(self):  # pragma: no cover
         return len(self._store)
 
-    def __copy__(self):
+    def __copy__(self):  # pragma: no cover
         return CaseInsensitiveDict(self._store)
 
     def lower_case_items(self):
@@ -62,31 +63,50 @@ class CaseInsensitiveDict(MutableMapping):
     def __eq__(self, other):
         if isinstance(other, MutableMapping):
             other = CaseInsensitiveDict(other)
-        else:
+        else:   # pragma: no cover
             raise NotImplementedError
 
         return dict(self.lower_case_items()) == dict(other.lower_case_items())
 
 
-class RobotsTxt(RobotFileParser, object):
-    """ Provides a error tolerant python form of robots.txt
+class RobotsTxtParser(RobotFileParser):
+    """Reads the robots.txt from the site.
 
-    Example:
-        >>> rp = RobotsTxt('*', url='http://some-site.com/robots.txt')
+    Usage::
+        >>> rp = RobotsTxtParser(user_agent='*', url='http://some-site.com/robots.txt')
+        >>> rp.read()
         >>> rp.can_fetch('/hidden/url_path')
-        False
+        >>> False
         >>> rp.can_fetch('/public/url_path/')
-        True
+        >>> True
 
     """
+    user_agent = '*'
+    _get = None
 
-    def __init__(self, user_agent, url):
-        self.url = url
-        self.user_agent = user_agent
-        super(RobotsTxt, self).__init__(self.url)
+    def set_ua(self, ua):
+        self.user_agent = ua
 
-    def can_fetch(self, url, *args, **kwargs):
-        if not self.url or url:
-            return True
+    def read(self):
+        """Modify the read method to use the inbuilt http session instead
+        of using a new raw urllib connection.
+
+        This usually sets up a session and a cookie jar.
+        Thus subsequent requests should be faster.
+        """
+        try:
+            f = self._get(self.url)
+            f.raise_for_status()
+        except requests.exceptions.HTTPError as err:
+            code = err.response.status_code
+            if code in (401, 403):
+                self.disallow_all = True
+            elif 400 <= code < 500:
+                self.allow_all = True
+        except requests.exceptions.ConnectionError:
+            self.allow_all = True
         else:
-            super(RobotsTxt, self).can_fetch(self.user_agent, url)
+            self.parse(f.text.splitlines())
+
+    def can_fetch(self, url, user_agent=None):
+        return super(RobotsTxtParser, self).can_fetch(user_agent or self.user_agent, url)
